============
Contributors
============

* Claudio Navacchi (cnavacch) <claudio.navacchi@geo.tuwien.ac.at>
* Sebastian Hahn (sebhahn) <sebastian.hahn@geo.tuwien.ac.at>
* Bernhard Raml (SwamyDev) <bernhard.raml@geo.tuwien.ac.at>
* Bernhard Bauer-Marschallinger <bbm@geo.tuwien.ac.at>
* Leonard Weydemann (lweydemann) <leonard.weydemann@geo.tuwien.ac.at>

